In 2024, NetEase launched a new server called "Elemental Poetry" which includes musical instruments that I love to play. But the instrument only has two octaves, which is very difficult to hold. So I converted some of my favorite song sheet music adaptations into electronic sheet music and script code, and put them in a place where the pip command can be obtained for everyone to download. I hope you like my adaptations.